@@ -8,22 +8,20 @@
 #include "widgets/transportmanagementwidget.h"
 
 #include <KPluginFactory>
-#include <KPluginLoader>
 
 #include <QVBoxLayout>
 
 using namespace MailTransport;
 
-K_PLUGIN_FACTORY(MailTransportConfigFactory, registerPlugin<ConfigModule>();
-                 )
+K_PLUGIN_FACTORY(MailTransportConfigFactory, registerPlugin<ConfigModule>();)
 
 ConfigModule::ConfigModule(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
 {
     setButtons(NoAdditionalButton);
-    auto *l = new QVBoxLayout(this);
-    l->setContentsMargins(0, 0, 0, 0);
-    auto *tmw = new TransportManagementWidget(this);
+    auto l = new QVBoxLayout(this);
+    l->setContentsMargins({});
+    auto tmw = new TransportManagementWidget(this);
     l->addWidget(tmw);
 }
 
