@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ SMTPMailTransportPlugin::SMTPMailTransportPlugin(QObject *parent, const QList<QV
 {
 }
 
-SMTPMailTransportPlugin::~SMTPMailTransportPlugin()
-{
-}
+SMTPMailTransportPlugin::~SMTPMailTransportPlugin() = default;
 
 QVector<MailTransport::TransportAbstractPluginInfo> SMTPMailTransportPlugin::names() const
 {
