@@ -16,6 +16,8 @@
 #include <KMessageBox>
 #include <KStringHandler>
 #include <KWallet>
+#include <kwidgetsaddons_version.h>
+
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <qt5keychain/keychain.h>
 #else
@@ -23,7 +25,6 @@
 #endif
 using namespace QKeychain;
 using namespace MailTransport;
-using namespace KWallet;
 
 Transport::Transport(const QString &cfgGroup)
     : TransportBase(cfgGroup)
@@ -187,7 +188,10 @@ void Transport::usrRead()
 
     if (!d->password.isEmpty()) {
         d->passwordLoaded = true;
-        if (Wallet::isEnabled()) {
+        if (KWallet::Wallet::isEnabled()) {
+            //TODO: Needs to replaced with a check, if a backend is available.
+            // 2022-10-12: QtKeyChain has no method to request, if there is any backend.
+            // see https://github.com/frankosterfeld/qtkeychain/issues/224
             d->needsWalletMigration = true;
         } else {
             d->storePasswordInFile = true;
@@ -199,30 +203,48 @@ bool Transport::usrSave()
 {
     if (requiresAuthentication() && storePassword() && d->passwordDirty) {
         const QString storePassword = d->password;
-        Wallet *wallet = TransportManager::self()->wallet();
-        if (!wallet || wallet->writePassword(QString::number(id()), d->password) != 0) {
-            // wallet saving failed, ask if we should store in the config file instead
-            if (d->storePasswordInFile
-                || KMessageBox::warningYesNo(nullptr,
-                                             i18n("KWallet is not available. It is strongly recommended to use "
-                                                  "KWallet for managing your passwords.\n"
-                                                  "However, the password can be stored in the configuration "
-                                                  "file instead. The password is stored in an obfuscated format, "
-                                                  "but should not be considered secure from decryption efforts "
-                                                  "if access to the configuration file is obtained.\n"
-                                                  "Do you want to store the password for server '%1' in the "
-                                                  "configuration file?",
-                                                  name()),
-                                             i18n("KWallet Not Available"),
-                                             KGuiItem(i18n("Store Password")),
-                                             KGuiItem(i18n("Do Not Store Password")))
+        auto writeJob = new WritePasswordJob(WALLET_FOLDER, this);
+        connect(writeJob, &Job::finished, this, [=]{
+            if (writeJob->error()) {
+                qWarning(MAILTRANSPORT_LOG()) << "WritePasswordJob failed with: " << writeJob->errorString();
+                // wallet saving failed, ask if we should store in the config file instead
+                if (d->storePasswordInFile
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                    || KMessageBox::warningTwoActions(nullptr,
+#else
+                    || KMessageBox::warningYesNo(nullptr,
+#endif
+                                                  i18n("QKeychain not found a backend for storing your password. "
+                                                       "It is strongly recommended to use strong backend for managing your passwords.\n"
+                                                       "However, the password can be stored in the configuration "
+                                                       "file instead. The password is stored in an obfuscated format, "
+                                                       "but should not be considered secure from decryption efforts "
+                                                       "if access to the configuration file is obtained.\n"
+                                                       "Do you want to store the password for server '%1' in the "
+                                                       "configuration file?",
+                                                       name()),
+                                                  i18n("KWallet Not Available"),
+                                                  KGuiItem(i18n("Store Password")),
+                                                  KGuiItem(i18n("Do Not Store Password")))
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                    == KMessageBox::ButtonCode::PrimaryAction) {
+#else
                     == KMessageBox::Yes) {
-                // write to config file
-                KConfigGroup group(config(), currentGroup());
-                group.writeEntry("password", KStringHandler::obscure(storePassword));
-                d->storePasswordInFile = true;
+#endif
+                    // write to config file
+                    KConfigGroup group(config(), currentGroup());
+                    group.writeEntry("password", KStringHandler::obscure(storePassword));
+                    d->storePasswordInFile = true;
+                }
             }
-        }
+        });
+
+        writeJob->setKey(QString::number(id()));
+        writeJob->setTextData(storePassword);
+        QEventLoop loop;
+        connect(writeJob, &Job::finished, &loop, &QEventLoop::quit);
+        writeJob->start();
+        loop.exec();
         d->passwordDirty = false;
     }
 
@@ -263,6 +285,7 @@ void Transport::readTransportPasswordFinished(QKeychain::Job *baseJob)
     } else {
         setPassword(job->textData());
     }
+    Q_EMIT passwordLoaded();
 }
 
 bool Transport::needsWalletMigration() const
