@@ -23,6 +23,7 @@
 #include <QRandomGenerator>
 #include <QRegularExpression>
 #include <QStringList>
+#include <kwidgetsaddons_version.h>
 
 #include "mailtransport_debug.h"
 #include <KConfig>
@@ -39,10 +40,8 @@
 #endif
 
 using namespace QKeychain;
-#include <KWallet>
 
 using namespace MailTransport;
-using namespace KWallet;
 
 namespace MailTransport
 {
@@ -69,12 +68,11 @@ public:
     TransportType::List types;
     bool myOwnChange = false;
     bool appliedChange = false;
-    KWallet::Wallet *wallet = nullptr;
-    bool walletOpenFailed = false;
     bool walletAsyncOpen = false;
     int defaultTransportId = -1;
     bool isMainInstance = false;
     QList<TransportJob *> walletQueue;
+    QMap<Transport*, QMetaObject::Connection> passwordConnections;
     TransportManager *const q;
 
     void readConfig();
@@ -88,8 +86,8 @@ public:
 
     // Slots
     void slotTransportsChanged();
-    void slotWalletOpened(bool success);
     void dbusServiceUnregistered();
+    void startQueuedJobs();
     void jobResult(KJob *job);
 };
 }
@@ -250,7 +248,8 @@ bool TransportManager::showTransportCreationDialog(QWidget *parent, ShowConditio
                                                      KMessageBox::WarningContinueCancel,
                                                      i18n("You must create an outgoing account before sending."),
                                                      i18n("Create Account Now?"),
-                                                     KGuiItem(i18n("Create Account Now")));
+                                                     KGuiItem(i18n("Create Account Now")),
+                                                     KStandardGuiItem::cancel());
         if (response != KMessageBox::Continue) {
             return false;
         }
@@ -533,117 +532,63 @@ int TransportManagerPrivate::createId() const
     return newId;
 }
 
-KWallet::Wallet *TransportManager::wallet()
-{
-    if (d->wallet && d->wallet->isOpen()) {
-        return d->wallet;
-    }
-
-    if (!Wallet::isEnabled() || d->walletOpenFailed) {
-        return nullptr;
-    }
-
-    WId window = 0;
-    if (qApp->activeWindow()) {
-        window = qApp->activeWindow()->winId();
-    } else if (!QApplication::topLevelWidgets().isEmpty()) {
-        window = qApp->topLevelWidgets().first()->winId();
-    }
-
-    delete d->wallet;
-    d->wallet = Wallet::openWallet(Wallet::NetworkWallet(), window);
-
-    if (!d->wallet) {
-        d->walletOpenFailed = true;
-        return nullptr;
-    }
-
-    d->prepareWallet();
-    return d->wallet;
-}
-
-void TransportManagerPrivate::prepareWallet()
-{
-    if (!wallet) {
-        return;
-    }
-    if (!wallet->hasFolder(WALLET_FOLDER)) {
-        wallet->createFolder(WALLET_FOLDER);
-    }
-    wallet->setFolder(WALLET_FOLDER);
-}
-
 void TransportManager::loadPasswords()
 {
+    QEventLoop loop;
     for (Transport *t : std::as_const(d->transports)) {
+        if (d->passwordConnections.contains(t)) {
+            continue;
+        }
+        auto conn = connect(t, &Transport::passwordLoaded, this, [&](){
+            disconnect(d->passwordConnections[t]);
+            d->passwordConnections.remove(t);
+            if (d->passwordConnections.count() == 0) {
+                loop.exit();
+            }
+        });
+        d->passwordConnections[t] = conn;
         t->readPassword();
     }
+    loop.exec();
 
-    // flush the wallet queue
-    const QList<TransportJob *> copy = d->walletQueue;
-    d->walletQueue.clear();
-    for (TransportJob *job : copy) {
-        job->start();
-    }
-
+    d->startQueuedJobs();
     Q_EMIT passwordsChanged();
 }
 
 void TransportManager::loadPasswordsAsync()
 {
-    qCDebug(MAILTRANSPORT_LOG);
-
-    // check if there is anything to do at all
-    bool found = false;
     for (Transport *t : std::as_const(d->transports)) {
         if (!t->isComplete()) {
-            found = true;
-            break;
-        }
-    }
-    if (!found) {
-        return;
-    }
-
-    // async wallet opening
-    if (!d->wallet && !d->walletOpenFailed) {
-        WId window = 0;
-        if (qApp->activeWindow()) {
-            window = qApp->activeWindow()->winId();
-        } else if (!QApplication::topLevelWidgets().isEmpty()) {
-            window = qApp->topLevelWidgets().first()->winId();
-        }
-
-        d->wallet = Wallet::openWallet(Wallet::NetworkWallet(), window, Wallet::Asynchronous);
-        // Already async. It will be easy to port to qt5keychain
-        if (d->wallet) {
-            connect(d->wallet, &KWallet::Wallet::walletOpened, this, [this](bool status) {
-                d->slotWalletOpened(status);
+            if (d->passwordConnections.contains(t)) {
+                continue;
+            }
+            auto conn = connect(t, &Transport::passwordLoaded, this, [&](){
+                disconnect(d->passwordConnections[t]);
+                d->passwordConnections.remove(t);
+                if (d->passwordConnections.count() == 0) {
+                    d->startQueuedJobs();
+                    Q_EMIT passwordsChanged();
+                }
             });
-            d->walletAsyncOpen = true;
-        } else {
-            d->walletOpenFailed = true;
-            loadPasswords();
+            d->passwordConnections[t] = conn;
+            t->readPassword();
         }
-        return;
-    }
-    if (d->wallet && !d->walletAsyncOpen) {
-        loadPasswords();
     }
 }
 
-void TransportManagerPrivate::slotWalletOpened(bool success)
+void TransportManagerPrivate::startQueuedJobs()
 {
-    qCDebug(MAILTRANSPORT_LOG);
-    walletAsyncOpen = false;
-    if (!success) {
-        walletOpenFailed = true;
-        delete wallet;
-        wallet = nullptr;
-    } else {
-        prepareWallet();
+    QList<TransportJob *> jobsToDel;
+    for (auto job : walletQueue) {
+        if (job->transport()->isComplete()) {
+            job->start();
+            jobsToDel << job;
+        }
+    }
+
+    for (auto job: jobsToDel) {
+        walletQueue.removeAll(job);
     }
-    q->loadPasswords();
 }
 
 void TransportManagerPrivate::validateDefault()
@@ -684,19 +629,27 @@ void TransportManagerPrivate::migrateToWallet()
     }
 
     // ask user if he wants to migrate
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    int result = KMessageBox::questionTwoActionsList(nullptr,
+#else
     int result = KMessageBox::questionYesNoList(nullptr,
-                                                i18n("The following mail transports store their passwords in an "
-                                                     "unencrypted configuration file.\nFor security reasons, "
-                                                     "please consider migrating these passwords to KWallet, the "
-                                                     "KDE Wallet management tool,\nwhich stores sensitive data "
-                                                     "for you in a strongly encrypted file.\n"
-                                                     "Do you want to migrate your passwords to KWallet?"),
-                                                names,
-                                                i18n("Question"),
-                                                KGuiItem(i18n("Migrate")),
-                                                KGuiItem(i18n("Keep")),
-                                                QStringLiteral("WalletMigrate"));
+#endif
+                                                     i18n("The following mail transports store their passwords in an "
+                                                          "unencrypted configuration file.\nFor security reasons, "
+                                                          "please consider migrating these passwords to KWallet, the "
+                                                          "KDE Wallet management tool,\nwhich stores sensitive data "
+                                                          "for you in a strongly encrypted file.\n"
+                                                          "Do you want to migrate your passwords to KWallet?"),
+                                                     names,
+                                                     i18n("Question"),
+                                                     KGuiItem(i18n("Migrate")),
+                                                     KGuiItem(i18n("Keep")),
+                                                     QStringLiteral("WalletMigrate"));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (result != KMessageBox::ButtonCode::PrimaryAction) {
+#else
     if (result != KMessageBox::Yes) {
+#endif
         return;
     }
 
